@@ -203,7 +203,7 @@ class Repository(object):
 
     def __init__(self, name, **kwds):
         class _TEMP_(object):
-            def __init__(self, root=None, trunk=None, stable=None, release=None, tag=None, pyname=None, pypi=None, dev=False, username=None, install=True, rev=None, local=None, platform=None, version=None, branch=None):
+            def __init__(self, root=None, trunk=None, stable=None, release=None, tag=None, pyname=None, pypi=None, dev=False, username=None, install=True, rev=None, local=None, platform=None, version=None, branch=None, exit=True):
                 import inspect
                 args, varargs, varkw, defaults = inspect.getargspec(self.__init__)
                 for i in range(len(args)-1):
@@ -222,6 +222,11 @@ class Repository(object):
                     self.config.install = False
                 else:
                     self.config.install = True
+            elif kwd == 'exit':
+                if kwds[kwd] == 'False' or kwds[kwd] is False:
+                    self.config.exit = False
+                else:
+                    self.config.exit = True
             else:
                 setattr(self.config, kwd, kwds[kwd])
         self.initialize(self.config)
@@ -359,6 +364,7 @@ class Repository(object):
             print >>OUTPUT, 'platform=%s' % config.platform
         if not config.version is None:
             print >>OUTPUT, 'version=%s' % config.version
+        print >>OUTPUT, 'exit=%s' % config.exit
 
 
     def find_pkgroot(self, trunk=False, stable=False, release=False):
@@ -449,7 +455,11 @@ class Repository(object):
             print ""
             print "Error: Cannot checkout software %s with subversion." % self.name
             print "A problem was detected executing subversion commands."
-            sys.exit(1)
+            if self.config.exit:
+                print "Aborting installer!"
+                sys.exit(1)
+            print "Not aborting installer..."
+            return
         else:
             print "-----------------------------------------------------------------"
             try:
@@ -458,7 +468,11 @@ class Repository(object):
                 print ""
                 print "Error checkout software %s with subversion at %s" % (self.name,self.pkgdir+self.rev)
                 print str(err)
-                sys.exit(1)
+                if self.config.exit:
+                    print "Aborting installer!"
+                    sys.exit(1)
+                print "Not aborting installer..."
+                return
         if install:
             try:
                 if self.dev:
@@ -473,7 +487,10 @@ class Repository(object):
                 print "Error installing software %s from source using the setup.py file." % self.name
                 print "This is probably due to a syntax or configuration error in this package."
                 print str(err)
-                sys.exit(1)
+                if self.config.exit:
+                    print "Aborting installer!"
+                    sys.exit(1)
+                print "Not aborting installer..."
 
     def update_trunk(self, dir=None):
         self.find_pkgroot(trunk=True)
@@ -518,7 +535,10 @@ class Repository(object):
             print ""
             print "Error installing package %s with easy_install" % self.name
             print str(err)
-            sys.exit(1)
+            if self.config.exit:
+                print "Aborting installer!"
+                sys.exit(1)
+            print "Not aborting installer..."
 
     def pip_install(self, install, preinstall, dir, offline):
         try:
@@ -534,7 +554,10 @@ class Repository(object):
             print ""
             print "Error installing package %s with pip" % self.name
             print str(err)
-            sys.exit(1)
+            if self.config.exit:
+                print "Aborting installer!"
+                sys.exit(1)
+            print "Not aborting installer..."
 
     def easy_upgrade(self):
         self.run(self.easy_install_path + [Repository.easy_install_flag, '--upgrade', self.pypi])
